==> webservices-osgi-2.4.2-sources.jar: com/sun/xml/ws/security/trust/elements/DelegateTo.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * $Id: DelegateTo.java,v 1.2 2010-10-21 15:35:40 snajper Exp $
 */

package com.sun.xml.ws.security.trust.elements;

import com.sun.xml.ws.security.trust.elements.str.SecurityTokenReference;
import com.sun.xml.ws.security.Token;

/**
 * Indicates that the requested or issued token be delegated to another
 * identity.
 *
 * @author WS-Trust Implementation Team.
 */
public interface DelegateTo {
    
    /**
     * Get the type of the DelegateTo information item
     *  @return {@link String}
     */
    String getTargetType();

   /**
     * Set the type of the DelegateTo information item
     *  @param targetType {@link String}
     */
    void setTargetType(String targetType);

    /**
     * Gets the value of the any property.
     * 
     * 
     * @return possible object is
     *     {@link Element }
     *     {@link Object }
     */
    Object getAny();

    /**
     * Sets the value of the any property.
     * 
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     */
    void setAny(Object value);
    
    /**
     * Set the STR for the Token as the contents of DelegateTo
     */
    void setSecurityTokenReference(SecurityTokenReference ref);
    
    /**
     * Get the STR contained in this DelegateTo instance
     */
    SecurityTokenReference getSecurityTokenReference();
    
    /**
     * Set the Token as the contents of DelegateTo
     */
    void setToken(Token token);
    
    /**
     * Get the Token contained in this DelegateTo instance
     */
    Token getToken();
}

==> webservices-osgi-2.4.6-sources.jar: com/sun/xml/ws/security/trust/elements/DelegateTo.java <==
/*
 * Copyright (c) 2010, 2021 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * $Id: DelegateTo.java,v 1.2 2010-10-21 15:35:40 snajper Exp $
 */

package com.sun.xml.ws.security.trust.elements;

import com.sun.xml.ws.security.trust.elements.str.SecurityTokenReference;
import com.sun.xml.ws.security.Token;

/**
 * Indicates that the requested or issued token be delegated to another
 * identity.
 *
 * @author WS-Trust Implementation Team.
 */
public interface DelegateTo {
    
    /**
     * Get the type of the DelegateTo information item
     *  @return {@link String}
     */
    String getTargetType();

   /**
     * Set the type of the DelegateTo information item
     *  @param targetType {@link String}
     */
    void setTargetType(String targetType);

    /**
     * Gets the value of the any property.
     * 
     * 
     * @return possible object is
     *     {@link org.w3c.dom.Element }
     *     {@link Object }
     */
    Object getAny();

    /**
     * Sets the value of the any property.
     * 
     * 
     * @param value
     *     allowed object is
     *     {@link org.w3c.dom.Element }
     *     {@link Object }
     */
    void setAny(Object value);
    
    /**
     * Set the STR for the Token as the contents of DelegateTo
     */
    void setSecurityTokenReference(SecurityTokenReference ref);
    
    /**
     * Get the STR contained in this DelegateTo instance
     */
    SecurityTokenReference getSecurityTokenReference();
    
    /**
     * Set the Token as the contents of DelegateTo
     */
    void setToken(Token token);
    
    /**
     * Get the Token contained in this DelegateTo instance
     */
    Token getToken();
}
